@@ -8,7 +8,8 @@ from . import ssdp
 __all__ = ['RXV']
 
 
-def find():
+def find(timeout=1.5):
     """Find all Yamah receivers on local network using SSDP search"""
-    return [RXV(ctrl_url=ri.ctrl_url, model_name=ri.model_name) for ri in ssdp.discover()]
+    return [RXV(ctrl_url=ri.ctrl_url, model_name=ri.model_name, friendly_name=ri.friendly_name)
+        for ri in ssdp.discover(timeout=1.5)]
 
